@@ -647,7 +647,7 @@ def _get_all_keys(config, key_prefix, delimiter):
         directories.extend(directories_page)
 
     return keys, directories
-
+    
 READ_HELPERS = {
 ('directory', 'json'): _get_folder,
 ('notebook', 'json'): _get_notebook,
@@ -672,11 +672,7 @@ def _copy_key_object(config, old_key, new_key):
     yield _copy_object(config, config.bucket_name, old_key, new_key)
 
 
-def _get_copy_key(curr_key):
-    if curr_key.endswith(FOLDER_SEPERATOR):
-        return (curr_key.count('/'),0)
-    else:
-        return (curr_key.count('/'),0)
+def _get_copy_key(key):
     return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
 
 def _delete_copy_key(key):
